Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2014-08-05 23:44:51 +0400
committerCampbell Barton <ideasman42@gmail.com>2014-08-05 23:46:31 +0400
commite56de9d9d55bd409832a22f533823f1954e85012 (patch)
treed6a77c5726f3829fc9cb563296decad203ad8975 /build_files/cmake/cmake_qtcreator_project.py
parentea9d94cf280bec54f6917789d56768a64646e0f7 (diff)
Remove SVN references
Diffstat (limited to 'build_files/cmake/cmake_qtcreator_project.py')
-rwxr-xr-xbuild_files/cmake/cmake_qtcreator_project.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build_files/cmake/cmake_qtcreator_project.py b/build_files/cmake/cmake_qtcreator_project.py
index 76f1efa6ccb..346f5ea6a8e 100755
--- a/build_files/cmake/cmake_qtcreator_project.py
+++ b/build_files/cmake/cmake_qtcreator_project.py
@@ -27,7 +27,7 @@ Example Win32 usage:
c:\Python32\python.exe c:\blender_dev\blender\build_files\cmake\cmake_qtcreator_project.py c:\blender_dev\cmake_build
example linux usage
- python .~/blenderSVN/blender/build_files/cmake/cmake_qtcreator_project.py ~/blenderSVN/cmake
+ python .~/blender-git/blender/build_files/cmake/cmake_qtcreator_project.py ~/blender-git/cmake
"""
from project_info import (SIMPLE_PROJECTFILE,
@@ -133,7 +133,7 @@ def create_qtc_project_python():
if 0:
PROJECT_NAME = "Blender_Python"
else:
# be tricky, get the project name from SVN if we can!
PROJECT_NAME = project_name_get() + "_Python"
FILE_NAME = PROJECT_NAME.lower()
@@ -133,7 +133,7 @@ def create_qtc_project_python():
PROJECT_NAME = "Blender_Python"
else:
- # be tricky, get the project name from SVN if we can!
+ # be tricky, get the project name from git if we can!
PROJECT_NAME = project_name_get() + "_Python"
FILE_NAME = PROJECT_NAME.lower()